package com.datacloudsec.scan.common;

import com.datacloudsec.utils.ObjectUtil;
import com.zaxxer.hikari.HikariDataSource;
import java.util.Properties;
import org.apache.ibatis.datasource.DataSourceFactory;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_common.jar:com/datacloudsec/scan/common/HikariCPDataSourceFactory.class */
public class HikariCPDataSourceFactory implements DataSourceFactory {
    private HikariDataSource dataSource = new HikariDataSource();
    private static final Logger LOG = Logger.getLogger(HikariCPDataSourceFactory.class);

    /* renamed from: getDataSource, reason: merged with bridge method [inline-methods] */
    public HikariDataSource m3getDataSource() {
        return this.dataSource;
    }

    public void setProperties(Properties properties) {
        try {
            this.dataSource.setDriverClassName(properties.getProperty("driver"));
            this.dataSource.setJdbcUrl(properties.getProperty("url"));
            this.dataSource.setUsername(properties.getProperty("username"));
            this.dataSource.setPassword(properties.getProperty("password"));
            this.dataSource.setPoolName("HikariCP");
            int minimumIdle = ObjectUtil.getInt(properties.getProperty("minimumIdle"), 0);
            if (minimumIdle != 0) {
                this.dataSource.setMinimumIdle(minimumIdle);
            }
            int maximumPoolSize = ObjectUtil.getInt(properties.getProperty("maximumPoolSize"), 0);
            if (maximumPoolSize != 0) {
                this.dataSource.setMaximumPoolSize(maximumPoolSize);
            }
            String testSql = ObjectUtil.getString(properties.getProperty("validationQuery"), (String) null);
            if (testSql != null) {
                this.dataSource.setConnectionTestQuery(testSql);
            }
            long connectionTimeout = ObjectUtil.getLong(properties.getProperty("connectionTimeout"), 0L).longValue();
            if (connectionTimeout != 0) {
                this.dataSource.setConnectionTimeout(connectionTimeout);
            }
            long idleTimeout = ObjectUtil.getLong(properties.getProperty("idleTimeout"), 0L).longValue();
            if (idleTimeout != 0) {
                this.dataSource.setIdleTimeout(idleTimeout);
            }
            long maxLifetime = ObjectUtil.getLong(properties.getProperty("maxLifetime"), 0L).longValue();
            if (maxLifetime != 0) {
                this.dataSource.setMaxLifetime(maxLifetime);
            }
            long leakDetectionThresholdMs = ObjectUtil.getLong(properties.getProperty("leakDetectionThresholdMs"), 0L).longValue();
            if (leakDetectionThresholdMs != 0) {
                this.dataSource.setLeakDetectionThreshold(leakDetectionThresholdMs);
            }
            this.dataSource.addDataSourceProperty("dataSource.cachePrepStmts", "true");
            this.dataSource.addDataSourceProperty("dataSource.prepStmtCacheSize", "250");
            this.dataSource.addDataSourceProperty("dataSource.prepStmtCacheSqlLimit", "2048");
            this.dataSource.addDataSourceProperty("dataSource.useServerPrepStmts", "true");
        } catch (Exception e) {
            LOG.error("读取数据库配置出错", e);
            this.dataSource.close();
            System.exit(0);
        }
    }
}
